pub struct AttFindByTypeValueResponse {
pub conn_handle: ConnectionHandle,
/* private fields */
}Expand description
This event is generated in response to a Find By Type Value Request.
Fields
conn_handle: ConnectionHandleThe connection handle related to the response.
Implementations
Sourceimpl AttFindByTypeValueResponse
impl AttFindByTypeValueResponse
Sourcepub fn handle_pairs_iter(&self) -> HandleInfoPairIterator<'_> ⓘ
pub fn handle_pairs_iter(&self) -> HandleInfoPairIterator<'_> ⓘ
Returns an iterator over the Handles Information List as defined in Bluetooth Core v4.1 spec.